# -*- coding: utf-8 -*-
# Generated by Django 1.9.8 on 2016-07-19 15:47
from django.db import migrations, models
import django.db.models.deletion
import modelcluster.fields
import shatail.blocks
import shatail.fields
import shatail.images.blocks


class Migration(migrations.Migration):

    dependencies = [
        ("shatailcore", "0029_unicode_slugfield_dj19"),
        ("tests", "0007_jadeformpage"),
    ]

    operations = [
        migrations.CreateModel(
            name="InlineStreamPage",
            fields=[
                (
                    "page_ptr",
                    models.OneToOneField(
                        auto_created=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        serialize=False,
                        to="shatailcore.Page",
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
            bases=("shatailcore.page",),
        ),
        migrations.CreateModel(
            name="InlineStreamPageSection",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "sort_order",
                    models.IntegerField(blank=True, editable=False, null=True),
                ),
                (
                    "body",
                    shatail.fields.StreamField(
                        (
                            ("text", shatail.blocks.CharBlock()),
                            ("rich_text", shatail.blocks.RichTextBlock()),
                            ("image", shatail.images.blocks.ImageChooserBlock()),
                        )
                    ),
                ),
                (
                    "page",
                    modelcluster.fields.ParentalKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="sections",
                        to="tests.InlineStreamPage",
                    ),
                ),
            ],
            options={
                "abstract": False,
                "ordering": ["sort_order"],
            },
        ),
    ]



from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class ShatailModelAdminAppConfig(AppConfig):
    name = "shatail.contrib.modeladmin"
    label = "shatailmodeladmin"
    verbose_name = _("Shatail ModelAdmin")



from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class ShatailRoutablePageAppConfig(AppConfig):
    name = "shatail.contrib.routable_page"
    label = "shatailroutablepage"
    verbose_name = _("Shatail routablepage")



from django.urls import path

from shatail.contrib.redirects import views

app_name = "shatailredirects"
urlpatterns = [
    path("", views.index, name="index"),
    path("add/", views.add, name="add"),
    path("<int:redirect_id>/", views.edit, name="edit"),
    path("<int:redirect_id>/delete/", views.delete, name="delete"),
    path("import/", views.start_import, name="start_import"),
    path("import/process/", views.process_import, name="process_import"),
    path("report", views.RedirectsReportView.as_view(), name="report"),
]



from shatail.admin.forms.models import ShatailAdminModelForm

from .models import Publisher


class PublisherModelAdminForm(ShatailAdminModelForm):
    class Meta:
        model = Publisher
        fields = ["name"]



from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class ShatailFormsAppConfig(AppConfig):
    name = "shatail.contrib.forms"
    label = "shatailforms"
    verbose_name = _("Shatail forms")
    default_auto_field = "django.db.models.AutoField"



from django.apps import AppConfig
from django.db.models import ForeignKey
from django.utils.translation import gettext_lazy as _

from . import get_document_model


class ShatailDocsAppConfig(AppConfig):
    name = "shatail.documents"
    label = "shataildocs"
    verbose_name = _("Shatail documents")
    default_auto_field = "django.db.models.AutoField"

    def ready(self):
        from shatail.documents.signal_handlers import register_signal_handlers

        register_signal_handlers()

        # Set up model forms to use AdminDocumentChooser for any ForeignKey to the document model
        from shatail.admin.forms.models import register_form_field_override

        from .widgets import AdminDocumentChooser

        Document = get_document_model()
        register_form_field_override(
            ForeignKey, to=Document, override={"widget": AdminDocumentChooser}
        )



from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class ShatailSearchPromotionsAppConfig(AppConfig):
    name = "shatail.contrib.search_promotions"
    label = "shatailsearchpromotions"
    verbose_name = _("Shatail search promotions")
    default_auto_field = "django.db.models.AutoField"



from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class ShatailAppConfig(AppConfig):
    name = "shatail"
    label = "shatailcore"
    verbose_name = _("Shatail core")
    default_auto_field = "django.db.models.AutoField"

    def ready(self):
        from shatail.signal_handlers import register_signal_handlers

        register_signal_handlers()

        from shatail import widget_adapters  # noqa



"""An alternative urlconf module where Shatail front-end URLs
are rooted at '/site/' rather than '/'"""

from django.urls import include, path

from shatail import urls as shatail_urls
from shatail.admin import urls as shatailadmin_urls
from shatail.documents import urls as shataildocs_urls
from shatail.images import urls as shatailimages_urls

urlpatterns = [
    path("admin/", include(shatailadmin_urls)),
    path("documents/", include(shataildocs_urls)),
    path("images/", include(shatailimages_urls)),
    path("site/", include(shatail_urls)),
]



from django.urls import path

from shatail import hooks
from shatail.api.v2.router import ShatailAPIRouter

from .views import PagesAdminAPIViewSet

admin_api = ShatailAPIRouter("shatailadmin_api")
admin_api.register_endpoint("pages", PagesAdminAPIViewSet)

for fn in hooks.get_hooks("construct_admin_api"):
    fn(admin_api)

urlpatterns = [
    path("main/", admin_api.urls),
]



from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class ShatailStyleGuideAppConfig(AppConfig):
    name = "shatail.contrib.styleguide"
    label = "shatailstyleguide"
    verbose_name = _("Shatail style guide")



from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _

from shatail.contrib.frontend_cache.signal_handlers import register_signal_handlers


class ShatailFrontendCacheAppConfig(AppConfig):
    name = "shatail.contrib.frontend_cache"
    label = "shatailfrontendcache"
    verbose_name = _("Shatail frontend cache")

    def ready(self):
        register_signal_handlers()



from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class ShatailSnippetsAppConfig(AppConfig):
    name = "shatail.snippets"
    label = "shatailsnippets"
    verbose_name = _("Shatail snippets")



from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class ShatailSitesAppConfig(AppConfig):
    name = "shatail.sites"
    label = "shatailsites"
    verbose_name = _("Shatail sites")



from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class ShatailTableBlockAppConfig(AppConfig):
    name = "shatail.contrib.table_block"
    label = "shatailtableblock"
    verbose_name = _("Shatail table block")



import json
from unittest import mock

from django.test import TestCase
from django.test.utils import override_settings
from django.urls import reverse

from shatail.api.v2 import signal_handlers
from shatail.documents import get_document_model


class TestDocumentListing(TestCase):
    fixtures = ["demosite.json"]

    def get_response(self, **params):
        return self.client.get(reverse("shatailapi_v2:documents:listing"), params)

    def get_document_id_list(self, content):
        return [document["id"] for document in content["items"]]

    # BASIC TESTS

    def test_basic(self):
        response = self.get_response()

        self.assertEqual(response.status_code, 200)
        self.assertEqual(response["Content-type"], "application/json")

        # Will crash if the JSON is invalid
        content = json.loads(response.content.decode("UTF-8"))

        # Check that the meta section is there
        self.assertIn("meta", content)
        self.assertIsInstance(content["meta"], dict)

        # Check that the total count is there and correct
        self.assertIn("total_count", content["meta"])
        self.assertIsInstance(content["meta"]["total_count"], int)
        self.assertEqual(
            content["meta"]["total_count"], get_document_model().objects.count()
        )

        # Check that the items section is there
        self.assertIn("items", content)
        self.assertIsInstance(content["items"], list)

        # Check that each document has a meta section with type and detail_url attributes
        for document in content["items"]:
            self.assertIn("meta", document)
            self.assertIsInstance(document["meta"], dict)
            self.assertEqual(
                set(document["meta"].keys()),
                {"type", "detail_url", "download_url", "tags"},
            )

            # Type should always be shataildocs.Document
            self.assertEqual(document["meta"]["type"], "shataildocs.Document")

            # Check detail_url
            self.assertEqual(
                document["meta"]["detail_url"],
                "http://localhost/api/main/documents/%d/" % document["id"],
            )

            # Check download_url
            self.assertTrue(
                document["meta"]["download_url"].startswith(
                    "http://localhost/documents/%d/" % document["id"]
                )
            )

    # FIELDS

    def test_fields_default(self):
        response = self.get_response()
        content = json.loads(response.content.decode("UTF-8"))

        for document in content["items"]:
            self.assertEqual(set(document.keys()), {"id", "meta", "title"})
            self.assertEqual(
                set(document["meta"].keys()),
                {"type", "detail_url", "download_url", "tags"},
            )

    def test_fields(self):
        response = self.get_response(fields="title")
        content = json.loads(response.content.decode("UTF-8"))

        for document in content["items"]:
            self.assertEqual(set(document.keys()), {"id", "meta", "title"})
            self.assertEqual(
                set(document["meta"].keys()),
                {"type", "detail_url", "download_url", "tags"},
            )

    def test_remove_fields(self):
        response = self.get_response(fields="-title")
        content = json.loads(response.content.decode("UTF-8"))

        for document in content["items"]:
            self.assertEqual(set(document.keys()), {"id", "meta"})

    def test_remove_meta_fields(self):
        response = self.get_response(fields="-download_url")
        content = json.loads(response.content.decode("UTF-8"))

        for document in content["items"]:
            self.assertEqual(set(document.keys()), {"id", "meta", "title"})
            self.assertEqual(
                set(document["meta"].keys()), {"type", "detail_url", "tags"}
            )

    def test_remove_all_meta_fields(self):
        response = self.get_response(fields="-type,-detail_url,-tags,-download_url")
        content = json.loads(response.content.decode("UTF-8"))

        for document in content["items"]:
            self.assertEqual(set(document.keys()), {"id", "title"})

    def test_remove_id_field(self):
        response = self.get_response(fields="-id")
        content = json.loads(response.content.decode("UTF-8"))

        for document in content["items"]:
            self.assertEqual(set(document.keys()), {"meta", "title"})

    def test_all_fields(self):
        response = self.get_response(fields="*")
        content = json.loads(response.content.decode("UTF-8"))

        for document in content["items"]:
            self.assertEqual(set(document.keys()), {"id", "meta", "title"})
            self.assertEqual(
                set(document["meta"].keys()),
                {"type", "detail_url", "tags", "download_url"},
            )

    def test_all_fields_then_remove_something(self):
        response = self.get_response(fields="*,-title,-download_url")
        content = json.loads(response.content.decode("UTF-8"))

        for document in content["items"]:
            self.assertEqual(set(document.keys()), {"id", "meta"})
            self.assertEqual(
                set(document["meta"].keys()), {"type", "detail_url", "tags"}
            )

    def test_fields_tags(self):
        response = self.get_response(fields="tags")
        content = json.loads(response.content.decode("UTF-8"))

        for document in content["items"]:
            self.assertIsInstance(document["meta"]["tags"], list)

    def test_star_in_wrong_position_gives_error(self):
        response = self.get_response(fields="title,*")
        content = json.loads(response.content.decode("UTF-8"))

        self.assertEqual(response.status_code, 400)
        self.assertEqual(
            content, {"message": "fields error: '*' must be in the first position"}
        )

    def test_fields_which_are_not_in_api_fields_gives_error(self):
        response = self.get_response(fields="uploaded_by_user")
        content = json.loads(response.content.decode("UTF-8"))

        self.assertEqual(response.status_code, 400)
        self.assertEqual(content, {"message": "unknown fields: uploaded_by_user"})

    def test_fields_unknown_field_gives_error(self):
        response = self.get_response(fields="123,title,abc")
        content = json.loads(response.content.decode("UTF-8"))

        self.assertEqual(response.status_code, 400)
        self.assertEqual(content, {"message": "unknown fields: 123, abc"})

    def test_fields_remove_unknown_field_gives_error(self):
        response = self.get_response(fields="-123,-title,-abc")
        content = json.loads(response.content.decode("UTF-8"))

        self.assertEqual(response.status_code, 400)
        self.assertEqual(content, {"message": "unknown fields: 123, abc"})

    # FILTERING

    def test_filtering_exact_filter(self):
        response = self.get_response(title="James Joyce")
        content = json.loads(response.content.decode("UTF-8"))

        document_id_list = self.get_document_id_list(content)
        self.assertEqual(document_id_list, [2])

    def test_filtering_on_id(self):
        response = self.get_response(id=10)
        content = json.loads(response.content.decode("UTF-8"))

        document_id_list = self.get_document_id_list(content)
        self.assertEqual(document_id_list, [10])

    def test_filtering_tags(self):
        get_document_model().objects.get(id=3).tags.add("test")

        response = self.get_response(tags="test")
        content = json.loads(response.content.decode("UTF-8"))

        document_id_list = self.get_document_id_list(content)
        self.assertEqual(document_id_list, [3])

    def test_filtering_unknown_field_gives_error(self):
        response = self.get_response(not_a_field="abc")
        content = json.loads(response.content.decode("UTF-8"))

        self.assertEqual(response.status_code, 400)
        self.assertEqual(
            content,
            {
                "message": "query parameter is not an operation or a recognised field: not_a_field"
            },
        )

    # ORDERING

    def test_ordering_by_title(self):
        response = self.get_response(order="title")
        content = json.loads(response.content.decode("UTF-8"))

        document_id_list = self.get_document_id_list(content)
        self.assertEqual(document_id_list, [3, 12, 10, 2, 7, 8, 5, 4, 1, 11, 9, 6])

    def test_ordering_by_title_backwards(self):
        response = self.get_response(order="-title")
        content = json.loads(response.content.decode("UTF-8"))

        document_id_list = self.get_document_id_list(content)
        self.assertEqual(document_id_list, [6, 9, 11, 1, 4, 5, 8, 7, 2, 10, 12, 3])

    def test_ordering_by_random(self):
        response_1 = self.get_response(order="random")
        content_1 = json.loads(response_1.content.decode("UTF-8"))
        document_id_list_1 = self.get_document_id_list(content_1)

        response_2 = self.get_response(order="random")
        content_2 = json.loads(response_2.content.decode("UTF-8"))
        document_id_list_2 = self.get_document_id_list(content_2)

        self.assertNotEqual(document_id_list_1, document_id_list_2)

    def test_ordering_by_random_backwards_gives_error(self):
        response = self.get_response(order="-random")
        content = json.loads(response.content.decode("UTF-8"))

        self.assertEqual(response.status_code, 400)
        self.assertEqual(
            content, {"message": "cannot order by 'random' (unknown field)"}
        )

    def test_ordering_by_random_with_offset_gives_error(self):
        response = self.get_response(order="random", offset=10)
        content = json.loads(response.content.decode("UTF-8"))

        self.assertEqual(response.status_code, 400)
        self.assertEqual(
            content, {"message": "random ordering with offset is not supported"}
        )

    def test_ordering_by_unknown_field_gives_error(self):
        response = self.get_response(order="not_a_field")
        content = json.loads(response.content.decode("UTF-8"))

        self.assertEqual(response.status_code, 400)
        self.assertEqual(
            content, {"message": "cannot order by 'not_a_field' (unknown field)"}
        )

    # LIMIT

    def test_limit_only_two_items_returned(self):
        response = self.get_response(limit=2)
        content = json.loads(response.content.decode("UTF-8"))

        self.assertEqual(len(content["items"]), 2)

    def test_limit_total_count(self):
        response = self.get_response(limit=2)
        content = json.loads(response.content.decode("UTF-8"))

        # The total count must not be affected by "limit"
        self.assertEqual(
            content["meta"]["total_count"], get_document_model().objects.count()
        )

    def test_limit_not_integer_gives_error(self):
        response = self.get_response(limit="abc")
        content = json.loads(response.content.decode("UTF-8"))

        self.assertEqual(response.status_code, 400)
        self.assertEqual(content, {"message": "limit must be a positive integer"})

    def test_limit_too_high_gives_error(self):
        response = self.get_response(limit=1000)
        content = json.loads(response.content.decode("UTF-8"))

        self.assertEqual(response.status_code, 400)
        self.assertEqual(content, {"message": "limit cannot be higher than 20"})

    @override_settings(SHATAILAPI_LIMIT_MAX=None)
    def test_limit_max_none_gives_no_errors(self):
        response = self.get_response(limit=1000000)
        content = json.loads(response.content.decode("UTF-8"))

        self.assertEqual(response.status_code, 200)
        self.assertEqual(len(content["items"]), get_document_model().objects.count())

    @override_settings(SHATAILAPI_LIMIT_MAX=10)
    def test_limit_maximum_can_be_changed(self):
        response = self.get_response(limit=20)
        content = json.loads(response.content.decode("UTF-8"))

        self.assertEqual(response.status_code, 400)
        self.assertEqual(content, {"message": "limit cannot be higher than 10"})

    @override_settings(SHATAILAPI_LIMIT_MAX=2)
    def test_limit_default_changes_with_max(self):
        # The default limit is 20. If SHATAILAPI_LIMIT_MAX is less than that,
        # the default should change accordingly.
        response = self.get_response()
        content = json.loads(response.content.decode("UTF-8"))

        self.assertEqual(len(content["items"]), 2)

    # OFFSET

    def test_offset_5_usually_appears_5th_in_list(self):
        response = self.get_response()
        content = json.loads(response.content.decode("UTF-8"))
        document_id_list = self.get_document_id_list(content)
        self.assertEqual(document_id_list.index(5), 4)

    def test_offset_5_moves_after_offset(self):
        response = self.get_response(offset=4)
        content = json.loads(response.content.decode("UTF-8"))
        document_id_list = self.get_document_id_list(content)
        self.assertEqual(document_id_list.index(5), 0)

    def test_offset_total_count(self):
        response = self.get_response(offset=10)
        content = json.loads(response.content.decode("UTF-8"))

        # The total count must not be affected by "offset"
        self.assertEqual(
            content["meta"]["total_count"], get_document_model().objects.count()
        )

    def test_offset_not_integer_gives_error(self):
        response = self.get_response(offset="abc")
        content = json.loads(response.content.decode("UTF-8"))

        self.assertEqual(response.status_code, 400)
        self.assertEqual(content, {"message": "offset must be a positive integer"})

    # SEARCH

    def test_search_for_james_joyce(self):
        response = self.get_response(search="james")
        content = json.loads(response.content.decode("UTF-8"))

        document_id_list = self.get_document_id_list(content)

        self.assertEqual(set(document_id_list), {2})

    def test_search_with_order(self):
        response = self.get_response(search="james", order="title")
        content = json.loads(response.content.decode("UTF-8"))

        document_id_list = self.get_document_id_list(content)

        self.assertEqual(document_id_list, [2])

    @override_settings(SHATAILAPI_SEARCH_ENABLED=False)
    def test_search_when_disabled_gives_error(self):
        response = self.get_response(search="james")
        content = json.loads(response.content.decode("UTF-8"))

        self.assertEqual(response.status_code, 400)
        self.assertEqual(content, {"message": "search is disabled"})

    def test_search_when_filtering_by_tag_gives_error(self):
        response = self.get_response(search="james", tags="shatail")
        content = json.loads(response.content.decode("UTF-8"))

        self.assertEqual(response.status_code, 400)
        self.assertEqual(
            content,
            {"message": "filtering by tag with a search query is not supported"},
        )


class TestDocumentDetail(TestCase):
    fixtures = ["demosite.json"]

    def get_response(self, image_id, **params):
        return self.client.get(
            reverse("shatailapi_v2:documents:detail", args=(image_id,)), params
        )

    def test_basic(self):
        response = self.get_response(1)

        self.assertEqual(response.status_code, 200)
        self.assertEqual(response["Content-type"], "application/json")

        # Will crash if the JSON is invalid
        content = json.loads(response.content.decode("UTF-8"))

        # Check the id field
        self.assertIn("id", content)
        self.assertEqual(content["id"], 1)

        # Check that the meta section is there
        self.assertIn("meta", content)
        self.assertIsInstance(content["meta"], dict)

        # Check the meta type
        self.assertIn("type", content["meta"])
        self.assertEqual(content["meta"]["type"], "shataildocs.Document")

        # Check the meta detail_url
        self.assertIn("detail_url", content["meta"])
        self.assertEqual(
            content["meta"]["detail_url"], "http://localhost/api/main/documents/1/"
        )

        # Check the meta download_url
        self.assertIn("download_url", content["meta"])
        self.assertEqual(
            content["meta"]["download_url"],
            "http://localhost/documents/1/shatail_by_markyharky.jpg",
        )

        # Check the title field
        self.assertIn("title", content)
        self.assertEqual(content["title"], "Shatail by mark Harkin")

        # Check the tags field
        self.assertIn("tags", content["meta"])
        self.assertEqual(content["meta"]["tags"], [])

    def test_tags(self):
        get_document_model().objects.get(id=1).tags.add("hello")
        get_document_model().objects.get(id=1).tags.add("world")

        response = self.get_response(1)
        content = json.loads(response.content.decode("UTF-8"))

        self.assertIn("tags", content["meta"])
        self.assertEqual(content["meta"]["tags"], ["hello", "world"])

    @override_settings(SHATAILAPI_BASE_URL="http://api.example.com/")
    def test_download_url_with_custom_base_url(self):
        response = self.get_response(1)
        content = json.loads(response.content.decode("UTF-8"))

        self.assertIn("download_url", content["meta"])
        self.assertEqual(
            content["meta"]["download_url"],
            "http://api.example.com/documents/1/shatail_by_markyharky.jpg",
        )

    # FIELDS

    def test_remove_fields(self):
        response = self.get_response(2, fields="-title")
        content = json.loads(response.content.decode("UTF-8"))

        self.assertIn("id", set(content.keys()))
        self.assertNotIn("title", set(content.keys()))

    def test_remove_meta_fields(self):
        response = self.get_response(2, fields="-download_url")
        content = json.loads(response.content.decode("UTF-8"))

        self.assertIn("detail_url", set(content["meta"].keys()))
        self.assertNotIn("download_url", set(content["meta"].keys()))

    def test_remove_id_field(self):
        response = self.get_response(2, fields="-id")
        content = json.loads(response.content.decode("UTF-8"))

        self.assertIn("title", set(content.keys()))
        self.assertNotIn("id", set(content.keys()))

    def test_remove_all_fields(self):
        response = self.get_response(2, fields="_,id,type")
        content = json.loads(response.content.decode("UTF-8"))

        self.assertEqual(set(content.keys()), {"id", "meta"})
        self.assertEqual(set(content["meta"].keys()), {"type"})

    def test_star_in_wrong_position_gives_error(self):
        response = self.get_response(2, fields="title,*")
        content = json.loads(response.content.decode("UTF-8"))

        self.assertEqual(response.status_code, 400)
        self.assertEqual(
            content, {"message": "fields error: '*' must be in the first position"}
        )

    def test_fields_which_are_not_in_api_fields_gives_error(self):
        response = self.get_response(2, fields="path")
        content = json.loads(response.content.decode("UTF-8"))

        self.assertEqual(response.status_code, 400)
        self.assertEqual(content, {"message": "unknown fields: path"})

    def test_fields_unknown_field_gives_error(self):
        response = self.get_response(2, fields="123,title,abc")
        content = json.loads(response.content.decode("UTF-8"))

        self.assertEqual(response.status_code, 400)
        self.assertEqual(content, {"message": "unknown fields: 123, abc"})

    def test_fields_remove_unknown_field_gives_error(self):
        response = self.get_response(2, fields="-123,-title,-abc")
        content = json.loads(response.content.decode("UTF-8"))

        self.assertEqual(response.status_code, 400)
        self.assertEqual(content, {"message": "unknown fields: 123, abc"})

    def test_nested_fields_on_non_relational_field_gives_error(self):
        response = self.get_response(2, fields="title(foo,bar)")
        content = json.loads(response.content.decode("UTF-8"))

        self.assertEqual(response.status_code, 400)
        self.assertEqual(content, {"message": "'title' does not support nested fields"})


class TestDocumentFind(TestCase):
    fixtures = ["demosite.json"]

    def get_response(self, **params):
        return self.client.get(reverse("shatailapi_v2:documents:find"), params)

    def test_without_parameters(self):
        response = self.get_response()

        self.assertEqual(response.status_code, 404)
        self.assertEqual(response["Content-type"], "application/json")

        # Will crash if the JSON is invalid
        content = json.loads(response.content.decode("UTF-8"))

        self.assertEqual(content, {"message": "not found"})

    def test_find_by_id(self):
        response = self.get_response(id=5)

        self.assertRedirects(
            response,
            "http://localhost" + reverse("shatailapi_v2:documents:detail", args=[5]),
            fetch_redirect_response=False,
        )

    def test_find_by_id_nonexistent(self):
        response = self.get_response(id=1234)

        self.assertEqual(response.status_code, 404)
        self.assertEqual(response["Content-type"], "application/json")

        # Will crash if the JSON is invalid
        content = json.loads(response.content.decode("UTF-8"))

        self.assertEqual(content, {"message": "not found"})


@override_settings(
    SHATAILFRONTENDCACHE={
        "varnish": {
            "BACKEND": "shatail.contrib.frontend_cache.backends.HTTPBackend",
            "LOCATION": "http://localhost:8000",
        },
    },
    SHATAILAPI_BASE_URL="http://api.example.com",
)
@mock.patch("shatail.contrib.frontend_cache.backends.HTTPBackend.purge")
class TestDocumentCacheInvalidation(TestCase):
    fixtures = ["demosite.json"]

    @classmethod
    def setUpClass(cls):
        super(TestDocumentCacheInvalidation, cls).setUpClass()
        signal_handlers.register_signal_handlers()

    @classmethod
    def tearDownClass(cls):
        super(TestDocumentCacheInvalidation, cls).tearDownClass()
        signal_handlers.unregister_signal_handlers()

    def test_resave_document_purges(self, purge):
        get_document_model().objects.get(id=5).save()

        purge.assert_any_call("http://api.example.com/api/main/documents/5/")

    def test_delete_document_purges(self, purge):
        get_document_model().objects.get(id=5).delete()

        purge.assert_any_call("http://api.example.com/api/main/documents/5/")



# Generated by Django 3.0.9 on 2020-08-12 20:27

from django.db import migrations
import shatail.blocks
import shatail.fields
import shatail.test.testapp.models


class Migration(migrations.Migration):

    dependencies = [
        ("tests", "0055_eventpage_childobject_i18n"),
    ]

    operations = [
        migrations.AlterField(
            model_name="streampage",
            name="body",
            field=shatail.fields.StreamField(
                [
                    ("text", shatail.blocks.CharBlock()),
                    ("rich_text", shatail.blocks.RichTextBlock()),
                    ("image", shatail.test.testapp.models.ExtendedImageChooserBlock()),
                    (
                        "product",
                        shatail.blocks.StructBlock(
                            [
                                ("name", shatail.blocks.CharBlock()),
                                ("price", shatail.blocks.CharBlock()),
                            ]
                        ),
                    ),
                    ("raw_html", shatail.blocks.RawHTMLBlock()),
                    (
                        "books",
                        shatail.blocks.StreamBlock(
                            [
                                ("title", shatail.blocks.CharBlock()),
                                ("author", shatail.blocks.CharBlock()),
                            ]
                        ),
                    ),
                ]
            ),
        ),
    ]



from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _

from .finders import get_finders


class ShatailEmbedsAppConfig(AppConfig):
    name = "shatail.embeds"
    label = "shatailembeds"
    verbose_name = _("Shatail embeds")
    default_auto_field = "django.db.models.AutoField"

    def ready(self):
        # Check configuration on startup
        get_finders()



# definitions which are not being deprecated from shatail.admin.forms
from .models import (  # NOQA
    DIRECT_FORM_FIELD_OVERRIDES,
    FORM_FIELD_OVERRIDES,
    ShatailAdminModelForm,
    ShatailAdminModelFormMetaclass,
    formfield_for_dbfield,
)
from .pages import ShatailAdminPageForm  # NOQA



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['shatail',
 'shatail.actions',
 'shatail.admin',
 'shatail.admin.api',
 'shatail.admin.api.actions',
 'shatail.admin.forms',
 'shatail.admin.migrations',
 'shatail.admin.rich_text',
 'shatail.admin.rich_text.converters',
 'shatail.admin.rich_text.editors',
 'shatail.admin.rich_text.editors.draftail',
 'shatail.admin.templatetags',
 'shatail.admin.tests',
 'shatail.admin.tests.api',
 'shatail.admin.tests.pages',
 'shatail.admin.tests.pages.test_bulk_actions',
 'shatail.admin.tests.ui',
 'shatail.admin.ui',
 'shatail.admin.urls',
 'shatail.admin.views',
 'shatail.admin.views.bulk_action',
 'shatail.admin.views.generic',
 'shatail.admin.views.pages',
 'shatail.admin.views.pages.bulk_actions',
 'shatail.admin.views.reports',
 'shatail.admin.viewsets',
 'shatail.admin.widgets',
 'shatail.api',
 'shatail.api.v2',
 'shatail.api.v2.tests',
 'shatail.bin',
 'shatail.blocks',
 'shatail.contrib',
 'shatail.contrib.forms',
 'shatail.contrib.forms.migrations',
 'shatail.contrib.forms.tests',
 'shatail.contrib.frontend_cache',
 'shatail.contrib.legacy.richtext.tests',
 'shatail.contrib.legacy.sitemiddleware',
 'shatail.contrib.modeladmin',
 'shatail.contrib.modeladmin.helpers',
 'shatail.contrib.modeladmin.templatetags',
 'shatail.contrib.modeladmin.tests',
 'shatail.contrib.redirects',
 'shatail.contrib.redirects.management',
 'shatail.contrib.redirects.management.commands',
 'shatail.contrib.redirects.migrations',
 'shatail.contrib.redirects.tests',
 'shatail.contrib.routable_page',
 'shatail.contrib.routable_page.templatetags',
 'shatail.contrib.search_promotions',
 'shatail.contrib.search_promotions.migrations',
 'shatail.contrib.search_promotions.templatetags',
 'shatail.contrib.settings',
 'shatail.contrib.settings.templatetags',
 'shatail.contrib.settings.tests',
 'shatail.contrib.simple_translation',
 'shatail.contrib.simple_translation.migrations',
 'shatail.contrib.simple_translation.tests',
 'shatail.contrib.sitemaps',
 'shatail.contrib.styleguide',
 'shatail.contrib.table_block',
 'shatail.contrib.table_block.templatetags',
 'shatail.contrib.typed_table_block',
 'shatail.core',
 'shatail.core.blocks',
 'shatail.core.models',
 'shatail.core.permission_policies',
 'shatail.core.rich_text',
 'shatail.core.templatetags',
 'shatail.documents',
 'shatail.documents.api',
 'shatail.documents.api.admin',
 'shatail.documents.api.v2',
 'shatail.documents.migrations',
 'shatail.documents.rich_text',
 'shatail.documents.tests',
 'shatail.documents.tests.test_bulk_actions',
 'shatail.documents.views',
 'shatail.documents.views.bulk_actions',
 'shatail.embeds',
 'shatail.embeds.finders',
 'shatail.embeds.migrations',
 'shatail.embeds.rich_text',
 'shatail.embeds.templatetags',
 'shatail.embeds.tests',
 'shatail.embeds.views',
 'shatail.images',
 'shatail.images.api',
 'shatail.images.api.admin',
 'shatail.images.api.v2',
 'shatail.images.management',
 'shatail.images.management.commands',
 'shatail.images.migrations',
 'shatail.images.rich_text',
 'shatail.images.templatetags',
 'shatail.images.tests',
 'shatail.images.tests.test_bulk_actions',
 'shatail.images.views',
 'shatail.images.views.bulk_actions',
 'shatail.locales',
 'shatail.management',
 'shatail.management.commands',
 'shatail.migrations',
 'shatail.models',
 'shatail.permission_policies',
 'shatail.project_template',
 'shatail.project_template.home',
 'shatail.project_template.home.migrations',
 'shatail.project_template.project_name',
 'shatail.project_template.project_name.settings',
 'shatail.project_template.search',
 'shatail.rich_text',
 'shatail.search',
 'shatail.search.backends',
 'shatail.search.backends.database',
 'shatail.search.backends.database.mysql',
 'shatail.search.backends.database.postgres',
 'shatail.search.backends.database.sqlite',
 'shatail.search.management',
 'shatail.search.management.commands',
 'shatail.search.migrations',
 'shatail.search.tests',
 'shatail.search.urls',
 'shatail.search.views',
 'shatail.sites',
 'shatail.snippets',
 'shatail.snippets.templatetags',
 'shatail.snippets.views',
 'shatail.templatetags',
 'shatail.test',
 'shatail.test.customuser',
 'shatail.test.customuser.migrations',
 'shatail.test.demosite',
 'shatail.test.demosite.migrations',
 'shatail.test.emailuser',
 'shatail.test.emailuser.migrations',
 'shatail.test.i18n',
 'shatail.test.i18n.migrations',
 'shatail.test.modeladmintest',
 'shatail.test.modeladmintest.migrations',
 'shatail.test.routablepage',
 'shatail.test.routablepage.migrations',
 'shatail.test.search',
 'shatail.test.search.migrations',
 'shatail.test.snippets',
 'shatail.test.snippets.migrations',
 'shatail.test.testapp',
 'shatail.test.testapp.migrations',
 'shatail.test.utils',
 'shatail.tests',
 'shatail.tests.utils',
 'shatail.users',
 'shatail.users.migrations',
 'shatail.users.templatetags',
 'shatail.users.tests',
 'shatail.users.tests.test_bulk_actions',
 'shatail.users.urls',
 'shatail.users.views',
 'shatail.users.views.bulk_actions',
 'shatail.utils']

package_data = \
{'': ['*'],
 'shatail': ['locale/af/LC_MESSAGES/*',
             'locale/ar/LC_MESSAGES/*',
             'locale/az_AZ/LC_MESSAGES/*',
             'locale/be/LC_MESSAGES/*',
             'locale/bg/LC_MESSAGES/*',
             'locale/bn/LC_MESSAGES/*',
             'locale/ca/LC_MESSAGES/*',
             'locale/cs/LC_MESSAGES/*',
             'locale/cy/LC_MESSAGES/*',
             'locale/da/LC_MESSAGES/*',
             'locale/de/LC_MESSAGES/*',
             'locale/el/LC_MESSAGES/*',
             'locale/en/LC_MESSAGES/*',
             'locale/es/LC_MESSAGES/*',
             'locale/et/LC_MESSAGES/*',
             'locale/eu/LC_MESSAGES/*',
             'locale/fa/LC_MESSAGES/*',
             'locale/fi/LC_MESSAGES/*',
             'locale/fr/LC_MESSAGES/*',
             'locale/gl/LC_MESSAGES/*',
             'locale/he_IL/LC_MESSAGES/*',
             'locale/hr_HR/LC_MESSAGES/*',
             'locale/hu/LC_MESSAGES/*',
             'locale/id_ID/LC_MESSAGES/*',
             'locale/is_IS/LC_MESSAGES/*',
             'locale/it/LC_MESSAGES/*',
             'locale/ja/LC_MESSAGES/*',
             'locale/ka/LC_MESSAGES/*',
             'locale/ko/LC_MESSAGES/*',
             'locale/lt/LC_MESSAGES/*',
             'locale/lv/LC_MESSAGES/*',
             'locale/mi/LC_MESSAGES/*',
             'locale/mn/LC_MESSAGES/*',
             'locale/my/LC_MESSAGES/*',
             'locale/nb/LC_MESSAGES/*',
             'locale/nl/LC_MESSAGES/*',
             'locale/pl/LC_MESSAGES/*',
             'locale/pt_BR/LC_MESSAGES/*',
             'locale/pt_PT/LC_MESSAGES/*',
             'locale/ro/LC_MESSAGES/*',
             'locale/ru/LC_MESSAGES/*',
             'locale/sk_SK/LC_MESSAGES/*',
             'locale/sl/LC_MESSAGES/*',
             'locale/sv/LC_MESSAGES/*',
             'locale/tet/LC_MESSAGES/*',
             'locale/th/LC_MESSAGES/*',
             'locale/tr/LC_MESSAGES/*',
             'locale/tr_TR/LC_MESSAGES/*',
             'locale/uk/LC_MESSAGES/*',
             'locale/vi/LC_MESSAGES/*',
             'locale/zh/LC_MESSAGES/*',
             'locale/zh_Hans/LC_MESSAGES/*',
             'locale/zh_Hant/LC_MESSAGES/*',
             'templates/shatailcore/*',
             'templates/shatailcore/shared/*'],
 'shatail.admin': ['locale/af/LC_MESSAGES/*',
                   'locale/ar/LC_MESSAGES/*',
                   'locale/az_AZ/LC_MESSAGES/*',
                   'locale/be/LC_MESSAGES/*',
                   'locale/bg/LC_MESSAGES/*',
                   'locale/bn/LC_MESSAGES/*',
                   'locale/ca/LC_MESSAGES/*',
                   'locale/cs/LC_MESSAGES/*',
                   'locale/cy/LC_MESSAGES/*',
                   'locale/da/LC_MESSAGES/*',
                   'locale/de/LC_MESSAGES/*',
                   'locale/el/LC_MESSAGES/*',
                   'locale/en/LC_MESSAGES/*',
                   'locale/es/LC_MESSAGES/*',
                   'locale/et/LC_MESSAGES/*',
                   'locale/eu/LC_MESSAGES/*',
                   'locale/fa/LC_MESSAGES/*',
                   'locale/fi/LC_MESSAGES/*',
                   'locale/fr/LC_MESSAGES/*',
                   'locale/gl/LC_MESSAGES/*',
                   'locale/he_IL/LC_MESSAGES/*',
                   'locale/hr_HR/LC_MESSAGES/*',
                   'locale/ht/LC_MESSAGES/*',
                   'locale/hu/LC_MESSAGES/*',
                   'locale/hy/LC_MESSAGES/*',
                   'locale/id_ID/LC_MESSAGES/*',
                   'locale/is_IS/LC_MESSAGES/*',
                   'locale/it/LC_MESSAGES/*',
                   'locale/ja/LC_MESSAGES/*',
                   'locale/ka/LC_MESSAGES/*',
                   'locale/ko/LC_MESSAGES/*',
                   'locale/lt/LC_MESSAGES/*',
                   'locale/lv/LC_MESSAGES/*',
                   'locale/mi/LC_MESSAGES/*',
                   'locale/mn/LC_MESSAGES/*',
                   'locale/my/LC_MESSAGES/*',
                   'locale/nb/LC_MESSAGES/*',
                   'locale/nl/LC_MESSAGES/*',
                   'locale/pl/LC_MESSAGES/*',
                   'locale/pt_BR/LC_MESSAGES/*',
                   'locale/pt_PT/LC_MESSAGES/*',
                   'locale/ro/LC_MESSAGES/*',
                   'locale/ru/LC_MESSAGES/*',
                   'locale/sk_SK/LC_MESSAGES/*',
                   'locale/sl/LC_MESSAGES/*',
                   'locale/sv/LC_MESSAGES/*',
                   'locale/tet/LC_MESSAGES/*',
                   'locale/th/LC_MESSAGES/*',
                   'locale/tr/LC_MESSAGES/*',
                   'locale/tr_TR/LC_MESSAGES/*',
                   'locale/uk/LC_MESSAGES/*',
                   'locale/vi/LC_MESSAGES/*',
                   'locale/zh/LC_MESSAGES/*',
                   'locale/zh_Hans/LC_MESSAGES/*',
                   'locale/zh_Hant/LC_MESSAGES/*',
                   'static_src/*',
                   'static_src/shatailadmin/*',
                   'static_src/shatailadmin/css/*',
                   'static_src/shatailadmin/css/vendor/*',
                   'static_src/shatailadmin/css/vendor/jquery-ui/*',
                   'static_src/shatailadmin/css/vendor/jquery-ui/images/*',
                   'static_src/shatailadmin/fonts/*',
                   'static_src/shatailadmin/images/*',
                   'static_src/shatailadmin/images/icons/*',
                   'static_src/shatailadmin/js/*',
                   'static_src/shatailadmin/js/vendor/*',
                   'static_src/shatailadmin/scss/*',
                   'static_src/shatailadmin/scss/layouts/*',
                   'static_src/shatailadmin/scss/panels/*',
                   'templates/*',
                   'templates/shatailadmin/*',
                   'templates/shatailadmin/account/*',
                   'templates/shatailadmin/account/password_reset/*',
                   'templates/shatailadmin/account/settings_panels/*',
                   'templates/shatailadmin/bulk_actions/*',
                   'templates/shatailadmin/bulk_actions/confirmation/*',
                   'templates/shatailadmin/chooser/*',
                   'templates/shatailadmin/collection_privacy/*',
                   'templates/shatailadmin/collections/*',
                   'templates/shatailadmin/generic/*',
                   'templates/shatailadmin/generic/multiple_upload/*',
                   'templates/shatailadmin/home/*',
                   'templates/shatailadmin/icons/*',
                   'templates/shatailadmin/notifications/*',
                   'templates/shatailadmin/page_privacy/*',
                   'templates/shatailadmin/pages/*',
                   'templates/shatailadmin/pages/action_menu/*',
                   'templates/shatailadmin/pages/bulk_actions/*',
                   'templates/shatailadmin/pages/listing/*',
                   'templates/shatailadmin/pages/revisions/*',
                   'templates/shatailadmin/pages/side_panels/*',
                   'templates/shatailadmin/pages/side_panels/includes/*',
                   'templates/shatailadmin/pages/workflow_history/*',
                   'templates/shatailadmin/panels/*',
                   'templates/shatailadmin/panels/comments/*',
                   'templates/shatailadmin/permissions/*',
                   'templates/shatailadmin/permissions/includes/*',
                   'templates/shatailadmin/reports/*',
                   'templates/shatailadmin/reports/listing/*',
                   'templates/shatailadmin/shared/*',
                   'templates/shatailadmin/shared/headers/*',
                   'templates/shatailadmin/shared/tabs/*',
                   'templates/shatailadmin/tables/*',
                   'templates/shatailadmin/userbar/*',
                   'templates/shatailadmin/widgets/*',
                   'templates/shatailadmin/workflows/*',
                   'templates/shatailadmin/workflows/includes/*',
                   'templates/shatailadmin/workflows/task_chooser/*',
                   'templates/shatailadmin/workflows/task_chooser/includes/*',
                   'templates/shatailadmin/workflows/widgets/*'],
 'shatail.contrib': ['legacy/*',
                     'legacy/richtext/*',
                     'legacy/richtext/templates/*',
                     'legacy/richtext/templates/shatailcore/*',
                     'legacy/richtext/templates/shatailcore/shared/*'],
 'shatail.contrib.forms': ['locale/af/LC_MESSAGES/*',
                           'locale/ar/LC_MESSAGES/*',
                           'locale/az_AZ/LC_MESSAGES/*',
                           'locale/be/LC_MESSAGES/*',
                           'locale/bg/LC_MESSAGES/*',
                           'locale/bn/LC_MESSAGES/*',
                           'locale/ca/LC_MESSAGES/*',
                           'locale/cs/LC_MESSAGES/*',
                           'locale/cy/LC_MESSAGES/*',
                           'locale/da/LC_MESSAGES/*',
                           'locale/de/LC_MESSAGES/*',
                           'locale/el/LC_MESSAGES/*',
                           'locale/en/LC_MESSAGES/*',
                           'locale/es/LC_MESSAGES/*',
                           'locale/et/LC_MESSAGES/*',
                           'locale/eu/LC_MESSAGES/*',
                           'locale/fa/LC_MESSAGES/*',
                           'locale/fi/LC_MESSAGES/*',
                           'locale/fr/LC_MESSAGES/*',
                           'locale/gl/LC_MESSAGES/*',
                           'locale/he_IL/LC_MESSAGES/*',
                           'locale/hr_HR/LC_MESSAGES/*',
                           'locale/ht/LC_MESSAGES/*',
                           'locale/hu/LC_MESSAGES/*',
                           'locale/hy/LC_MESSAGES/*',
                           'locale/id_ID/LC_MESSAGES/*',
                           'locale/is_IS/LC_MESSAGES/*',
                           'locale/it/LC_MESSAGES/*',
                           'locale/ja/LC_MESSAGES/*',
                           'locale/ka/LC_MESSAGES/*',
                           'locale/ko/LC_MESSAGES/*',
                           'locale/lt/LC_MESSAGES/*',
                           'locale/lv/LC_MESSAGES/*',
                           'locale/mi/LC_MESSAGES/*',
                           'locale/mn/LC_MESSAGES/*',
                           'locale/my/LC_MESSAGES/*',
                           'locale/nb/LC_MESSAGES/*',
                           'locale/nl/LC_MESSAGES/*',
                           'locale/pl/LC_MESSAGES/*',
                           'locale/pt_BR/LC_MESSAGES/*',
                           'locale/pt_PT/LC_MESSAGES/*',
                           'locale/ro/LC_MESSAGES/*',
                           'locale/ru/LC_MESSAGES/*',
                           'locale/sk_SK/LC_MESSAGES/*',
                           'locale/sl/LC_MESSAGES/*',
                           'locale/sv/LC_MESSAGES/*',
                           'locale/tet/LC_MESSAGES/*',
                           'locale/th/LC_MESSAGES/*',
                           'locale/tr/LC_MESSAGES/*',
                           'locale/tr_TR/LC_MESSAGES/*',
                           'locale/uk/LC_MESSAGES/*',
                           'locale/vi/LC_MESSAGES/*',
                           'locale/zh/LC_MESSAGES/*',
                           'locale/zh_Hans/LC_MESSAGES/*',
                           'locale/zh_Hant/LC_MESSAGES/*',
                           'templates/*',
                           'templates/shatailforms/*',
                           'templates/shatailforms/panels/*'],
 'shatail.contrib.modeladmin': ['locale/af/LC_MESSAGES/*',
                                'locale/ar/LC_MESSAGES/*',
                                'locale/az_AZ/LC_MESSAGES/*',
                                'locale/be/LC_MESSAGES/*',
                                'locale/bg/LC_MESSAGES/*',
                                'locale/bn/LC_MESSAGES/*',
                                'locale/ca/LC_MESSAGES/*',
                                'locale/cs/LC_MESSAGES/*',
                                'locale/cy/LC_MESSAGES/*',
                                'locale/da/LC_MESSAGES/*',
                                'locale/de/LC_MESSAGES/*',
                                'locale/el/LC_MESSAGES/*',
                                'locale/en/LC_MESSAGES/*',
                                'locale/es/LC_MESSAGES/*',
                                'locale/et/LC_MESSAGES/*',
                                'locale/eu/LC_MESSAGES/*',
                                'locale/fa/LC_MESSAGES/*',
                                'locale/fi/LC_MESSAGES/*',
                                'locale/fr/LC_MESSAGES/*',
                                'locale/gl/LC_MESSAGES/*',
                                'locale/he_IL/LC_MESSAGES/*',
                                'locale/hr_HR/LC_MESSAGES/*',
                                'locale/ht/LC_MESSAGES/*',
                                'locale/hu/LC_MESSAGES/*',
                                'locale/id_ID/LC_MESSAGES/*',
                                'locale/is_IS/LC_MESSAGES/*',
                                'locale/it/LC_MESSAGES/*',
                                'locale/ja/LC_MESSAGES/*',
                                'locale/ka/LC_MESSAGES/*',
                                'locale/ko/LC_MESSAGES/*',
                                'locale/lt/LC_MESSAGES/*',
                                'locale/lv/LC_MESSAGES/*',
                                'locale/mi/LC_MESSAGES/*',
                                'locale/mn/LC_MESSAGES/*',
                                'locale/my/LC_MESSAGES/*',
                                'locale/nb/LC_MESSAGES/*',
                                'locale/nl/LC_MESSAGES/*',
                                'locale/pl/LC_MESSAGES/*',
                                'locale/pt_BR/LC_MESSAGES/*',
                                'locale/pt_PT/LC_MESSAGES/*',
                                'locale/ro/LC_MESSAGES/*',
                                'locale/ru/LC_MESSAGES/*',
                                'locale/sk_SK/LC_MESSAGES/*',
                                'locale/sl/LC_MESSAGES/*',
                                'locale/sr/LC_MESSAGES/*',
                                'locale/sv/LC_MESSAGES/*',
                                'locale/tet/LC_MESSAGES/*',
                                'locale/th/LC_MESSAGES/*',
                                'locale/tr/LC_MESSAGES/*',
                                'locale/tr_TR/LC_MESSAGES/*',
                                'locale/uk/LC_MESSAGES/*',
                                'locale/vi/LC_MESSAGES/*',
                                'locale/zh/LC_MESSAGES/*',
                                'locale/zh_Hans/LC_MESSAGES/*',
                                'locale/zh_Hant/LC_MESSAGES/*',
                                'static_src/*',
                                'static_src/shatailmodeladmin/*',
                                'static_src/shatailmodeladmin/js/*',
                                'static_src/shatailmodeladmin/scss/*',
                                'templates/*',
                                'templates/modeladmin/*',
                                'templates/modeladmin/includes/*'],
 'shatail.contrib.redirects': ['locale/af/LC_MESSAGES/*',
                               'locale/ar/LC_MESSAGES/*',
                               'locale/az_AZ/LC_MESSAGES/*',
                               'locale/be/LC_MESSAGES/*',
                               'locale/bg/LC_MESSAGES/*',
                               'locale/bn/LC_MESSAGES/*',
                               'locale/ca/LC_MESSAGES/*',
                               'locale/cs/LC_MESSAGES/*',
                               'locale/cy/LC_MESSAGES/*',
                               'locale/da/LC_MESSAGES/*',
                               'locale/de/LC_MESSAGES/*',
                               'locale/el/LC_MESSAGES/*',
                               'locale/en/LC_MESSAGES/*',
                               'locale/es/LC_MESSAGES/*',
                               'locale/et/LC_MESSAGES/*',
                               'locale/eu/LC_MESSAGES/*',
                               'locale/fa/LC_MESSAGES/*',
                               'locale/fi/LC_MESSAGES/*',
                               'locale/fr/LC_MESSAGES/*',
                               'locale/gl/LC_MESSAGES/*',
                               'locale/he_IL/LC_MESSAGES/*',
                               'locale/hr_HR/LC_MESSAGES/*',
                               'locale/ht/LC_MESSAGES/*',
                               'locale/hu/LC_MESSAGES/*',
                               'locale/hy/LC_MESSAGES/*',
                               'locale/id_ID/LC_MESSAGES/*',
                               'locale/is_IS/LC_MESSAGES/*',
                               'locale/it/LC_MESSAGES/*',
                               'locale/ja/LC_MESSAGES/*',
                               'locale/ka/LC_MESSAGES/*',
                               'locale/ko/LC_MESSAGES/*',
                               'locale/lt/LC_MESSAGES/*',
                               'locale/lv/LC_MESSAGES/*',
                               'locale/mi/LC_MESSAGES/*',
                               'locale/mn/LC_MESSAGES/*',
                               'locale/my/LC_MESSAGES/*',
                               'locale/nb/LC_MESSAGES/*',
                               'locale/nl/LC_MESSAGES/*',
                               'locale/pl/LC_MESSAGES/*',
                               'locale/pt_BR/LC_MESSAGES/*',
                               'locale/pt_PT/LC_MESSAGES/*',
                               'locale/ro/LC_MESSAGES/*',
                               'locale/ru/LC_MESSAGES/*',
                               'locale/sk_SK/LC_MESSAGES/*',
                               'locale/sl/LC_MESSAGES/*',
                               'locale/sr/LC_MESSAGES/*',
                               'locale/sv/LC_MESSAGES/*',
                               'locale/tet/LC_MESSAGES/*',
                               'locale/th/LC_MESSAGES/*',
                               'locale/tr/LC_MESSAGES/*',
                               'locale/tr_TR/LC_MESSAGES/*',
                               'locale/uk/LC_MESSAGES/*',
                               'locale/vi/LC_MESSAGES/*',
                               'locale/zh/LC_MESSAGES/*',
                               'locale/zh_Hans/LC_MESSAGES/*',
                               'locale/zh_Hant/LC_MESSAGES/*',
                               'static/*',
                               'static/shatailredirects/*',
                               'static/shatailredirects/css/*',
                               'templates/*',
                               'templates/shatailredirects/*',
                               'templates/shatailredirects/reports/*'],
 'shatail.contrib.redirects.tests': ['files/*'],
 'shatail.contrib.search_promotions': ['locale/af/LC_MESSAGES/*',
                                       'locale/ar/LC_MESSAGES/*',
                                       'locale/az_AZ/LC_MESSAGES/*',
                                       'locale/be/LC_MESSAGES/*',
                                       'locale/bg/LC_MESSAGES/*',
                                       'locale/bn/LC_MESSAGES/*',
                                       'locale/ca/LC_MESSAGES/*',
                                       'locale/cs/LC_MESSAGES/*',
                                       'locale/cy/LC_MESSAGES/*',
                                       'locale/da/LC_MESSAGES/*',
                                       'locale/de/LC_MESSAGES/*',
                                       'locale/el/LC_MESSAGES/*',
                                       'locale/en/LC_MESSAGES/*',
                                       'locale/es/LC_MESSAGES/*',
                                       'locale/et/LC_MESSAGES/*',
                                       'locale/eu/LC_MESSAGES/*',
                                       'locale/fa/LC_MESSAGES/*',
                                       'locale/fi/LC_MESSAGES/*',
                                       'locale/fr/LC_MESSAGES/*',
                                       'locale/gl/LC_MESSAGES/*',
                                       'locale/he_IL/LC_MESSAGES/*',
                                       'locale/hr_HR/LC_MESSAGES/*',
                                       'locale/ht/LC_MESSAGES/*',
                                       'locale/hu/LC_MESSAGES/*',
                                       'locale/id_ID/LC_MESSAGES/*',
                                       'locale/is_IS/LC_MESSAGES/*',
                                       'locale/it/LC_MESSAGES/*',
                                       'locale/ja/LC_MESSAGES/*',
                                       'locale/ka/LC_MESSAGES/*',
                                       'locale/ko/LC_MESSAGES/*',
                                       'locale/lt/LC_MESSAGES/*',
                                       'locale/lv/LC_MESSAGES/*',
                                       'locale/mi/LC_MESSAGES/*',
                                       'locale/mn/LC_MESSAGES/*',
                                       'locale/my/LC_MESSAGES/*',
                                       'locale/nb/LC_MESSAGES/*',
                                       'locale/nl/LC_MESSAGES/*',
                                       'locale/pl/LC_MESSAGES/*',
                                       'locale/pt_BR/LC_MESSAGES/*',
                                       'locale/pt_PT/LC_MESSAGES/*',
                                       'locale/ro/LC_MESSAGES/*',
                                       'locale/ru/LC_MESSAGES/*',
                                       'locale/sk_SK/LC_MESSAGES/*',
                                       'locale/sl/LC_MESSAGES/*',
                                       'locale/sr/LC_MESSAGES/*',
                                       'locale/sv/LC_MESSAGES/*',
                                       'locale/tet/LC_MESSAGES/*',
                                       'locale/th/LC_MESSAGES/*',
                                       'locale/tr/LC_MESSAGES/*',
                                       'locale/tr_TR/LC_MESSAGES/*',
                                       'locale/uk/LC_MESSAGES/*',
                                       'locale/vi/LC_MESSAGES/*',
                                       'locale/zh/LC_MESSAGES/*',
                                       'locale/zh_Hans/LC_MESSAGES/*',
                                       'locale/zh_Hant/LC_MESSAGES/*',
                                       'templates/*',
                                       'templates/shatailsearchpromotions/*',
                                       'templates/shatailsearchpromotions/includes/*'],
 'shatail.contrib.settings': ['locale/af/LC_MESSAGES/*',
                              'locale/ar/LC_MESSAGES/*',
                              'locale/az_AZ/LC_MESSAGES/*',
                              'locale/be/LC_MESSAGES/*',
                              'locale/bg/LC_MESSAGES/*',
                              'locale/bn/LC_MESSAGES/*',
                              'locale/ca/LC_MESSAGES/*',
                              'locale/cs/LC_MESSAGES/*',
                              'locale/cy/LC_MESSAGES/*',
                              'locale/da/LC_MESSAGES/*',
                              'locale/de/LC_MESSAGES/*',
                              'locale/el/LC_MESSAGES/*',
                              'locale/en/LC_MESSAGES/*',
                              'locale/es/LC_MESSAGES/*',
                              'locale/et/LC_MESSAGES/*',
                              'locale/fa/LC_MESSAGES/*',
                              'locale/fi/LC_MESSAGES/*',
                              'locale/fr/LC_MESSAGES/*',
                              'locale/gl/LC_MESSAGES/*',
                              'locale/he_IL/LC_MESSAGES/*',
                              'locale/hr_HR/LC_MESSAGES/*',
                              'locale/ht/LC_MESSAGES/*',
                              'locale/hu/LC_MESSAGES/*',
                              'locale/id_ID/LC_MESSAGES/*',
                              'locale/is_IS/LC_MESSAGES/*',
                              'locale/it/LC_MESSAGES/*',
                              'locale/ja/LC_MESSAGES/*',
                              'locale/ka/LC_MESSAGES/*',
                              'locale/ko/LC_MESSAGES/*',
                              'locale/lt/LC_MESSAGES/*',
                              'locale/lv/LC_MESSAGES/*',
                              'locale/mi/LC_MESSAGES/*',
                              'locale/mn/LC_MESSAGES/*',
                              'locale/my/LC_MESSAGES/*',
                              'locale/nb/LC_MESSAGES/*',
                              'locale/nl/LC_MESSAGES/*',
                              'locale/pl/LC_MESSAGES/*',
                              'locale/pt_BR/LC_MESSAGES/*',
                              'locale/pt_PT/LC_MESSAGES/*',
                              'locale/ro/LC_MESSAGES/*',
                              'locale/ru/LC_MESSAGES/*',
                              'locale/sk_SK/LC_MESSAGES/*',
                              'locale/sl/LC_MESSAGES/*',
                              'locale/sr/LC_MESSAGES/*',
                              'locale/sv/LC_MESSAGES/*',
                              'locale/tet/LC_MESSAGES/*',
                              'locale/th/LC_MESSAGES/*',
                              'locale/tr/LC_MESSAGES/*',
                              'locale/tr_TR/LC_MESSAGES/*',
                              'locale/uk/LC_MESSAGES/*',
                              'locale/vi/LC_MESSAGES/*',
                              'locale/zh/LC_MESSAGES/*',
                              'locale/zh_Hans/LC_MESSAGES/*',
                              'locale/zh_Hant/LC_MESSAGES/*',
                              'static_src/shatailsettings/js/*',
                              'templates/*',
                              'templates/shatailsettings/*'],
 'shatail.contrib.simple_translation': ['locale/ca/LC_MESSAGES/*',
                                        'locale/cs/LC_MESSAGES/*',
                                        'locale/cy/LC_MESSAGES/*',
                                        'locale/de/LC_MESSAGES/*',
                                        'locale/el/LC_MESSAGES/*',
                                        'locale/en/LC_MESSAGES/*',
                                        'locale/es/LC_MESSAGES/*',
                                        'locale/fi/LC_MESSAGES/*',
                                        'locale/fr/LC_MESSAGES/*',
                                        'locale/hr_HR/LC_MESSAGES/*',
                                        'locale/hu/LC_MESSAGES/*',
                                        'locale/is_IS/LC_MESSAGES/*',
                                        'locale/it/LC_MESSAGES/*',
                                        'locale/lt/LC_MESSAGES/*',
                                        'locale/mi/LC_MESSAGES/*',
                                        'locale/nl/LC_MESSAGES/*',
                                        'locale/pl/LC_MESSAGES/*',
                                        'locale/pt_BR/LC_MESSAGES/*',
                                        'locale/pt_PT/LC_MESSAGES/*',
                                        'locale/ro/LC_MESSAGES/*',
                                        'locale/ru/LC_MESSAGES/*',
                                        'locale/sl/LC_MESSAGES/*',
                                        'locale/sv/LC_MESSAGES/*',
                                        'locale/uk/LC_MESSAGES/*',
                                        'locale/vi/LC_MESSAGES/*',
                                        'locale/zh_Hans/LC_MESSAGES/*',
                                        'locale/zh_Hant/LC_MESSAGES/*',
                                        'templates/*',
                                        'templates/simple_translation/*',
                                        'templates/simple_translation/admin/*'],
 'shatail.contrib.styleguide': ['locale/af/LC_MESSAGES/*',
                                'locale/ar/LC_MESSAGES/*',
                                'locale/az_AZ/LC_MESSAGES/*',
                                'locale/be/LC_MESSAGES/*',
                                'locale/bg/LC_MESSAGES/*',
                                'locale/bn/LC_MESSAGES/*',
                                'locale/ca/LC_MESSAGES/*',
                                'locale/cs/LC_MESSAGES/*',
                                'locale/cy/LC_MESSAGES/*',
                                'locale/da/LC_MESSAGES/*',
                                'locale/de/LC_MESSAGES/*',
                                'locale/el/LC_MESSAGES/*',
                                'locale/en/LC_MESSAGES/*',
                                'locale/es/LC_MESSAGES/*',
                                'locale/et/LC_MESSAGES/*',
                                'locale/eu/LC_MESSAGES/*',
                                'locale/fa/LC_MESSAGES/*',
                                'locale/fi/LC_MESSAGES/*',
                                'locale/fr/LC_MESSAGES/*',
                                'locale/gl/LC_MESSAGES/*',
                                'locale/he_IL/LC_MESSAGES/*',
                                'locale/hr_HR/LC_MESSAGES/*',
                                'locale/ht/LC_MESSAGES/*',
                                'locale/hu/LC_MESSAGES/*',
                                'locale/id_ID/LC_MESSAGES/*',
                                'locale/is_IS/LC_MESSAGES/*',
                                'locale/it/LC_MESSAGES/*',
                                'locale/ja/LC_MESSAGES/*',
                                'locale/ka/LC_MESSAGES/*',
                                'locale/ko/LC_MESSAGES/*',
                                'locale/lt/LC_MESSAGES/*',
                                'locale/lv/LC_MESSAGES/*',
                                'locale/mi/LC_MESSAGES/*',
                                'locale/mn/LC_MESSAGES/*',
                                'locale/my/LC_MESSAGES/*',
                                'locale/nb/LC_MESSAGES/*',
                                'locale/nl/LC_MESSAGES/*',
                                'locale/pl/LC_MESSAGES/*',
                                'locale/pt_BR/LC_MESSAGES/*',
                                'locale/pt_PT/LC_MESSAGES/*',
                                'locale/ro/LC_MESSAGES/*',
                                'locale/ru/LC_MESSAGES/*',
                                'locale/sk_SK/LC_MESSAGES/*',
                                'locale/sl/LC_MESSAGES/*',
                                'locale/sv/LC_MESSAGES/*',
                                'locale/tet/LC_MESSAGES/*',
                                'locale/th/LC_MESSAGES/*',
                                'locale/tr/LC_MESSAGES/*',
                                'locale/tr_TR/LC_MESSAGES/*',
                                'locale/uk/LC_MESSAGES/*',
                                'locale/vi/LC_MESSAGES/*',
                                'locale/zh/LC_MESSAGES/*',
                                'locale/zh_Hans/LC_MESSAGES/*',
                                'locale/zh_Hant/LC_MESSAGES/*',
                                'static_src/shatailstyleguide/scss/*',
                                'templates/shatailstyleguide/*'],
 'shatail.contrib.table_block': ['locale/ar/LC_MESSAGES/*',
                                 'locale/be/LC_MESSAGES/*',
                                 'locale/ca/LC_MESSAGES/*',
                                 'locale/cs/LC_MESSAGES/*',
                                 'locale/cy/LC_MESSAGES/*',
                                 'locale/de/LC_MESSAGES/*',
                                 'locale/el/LC_MESSAGES/*',
                                 'locale/en/LC_MESSAGES/*',
                                 'locale/es/LC_MESSAGES/*',
                                 'locale/et/LC_MESSAGES/*',
                                 'locale/fa/LC_MESSAGES/*',
                                 'locale/fi/LC_MESSAGES/*',
                                 'locale/fr/LC_MESSAGES/*',
                                 'locale/gl/LC_MESSAGES/*',
                                 'locale/hr_HR/LC_MESSAGES/*',
                                 'locale/ht/LC_MESSAGES/*',
                                 'locale/hu/LC_MESSAGES/*',
                                 'locale/id_ID/LC_MESSAGES/*',
                                 'locale/is_IS/LC_MESSAGES/*',
                                 'locale/it/LC_MESSAGES/*',
                                 'locale/ja/LC_MESSAGES/*',
                                 'locale/ko/LC_MESSAGES/*',
                                 'locale/lt/LC_MESSAGES/*',
                                 'locale/lv/LC_MESSAGES/*',
                                 'locale/mi/LC_MESSAGES/*',
                                 'locale/mn/LC_MESSAGES/*',
                                 'locale/my/LC_MESSAGES/*',
                                 'locale/nb/LC_MESSAGES/*',
                                 'locale/nl/LC_MESSAGES/*',
                                 'locale/pl/LC_MESSAGES/*',
                                 'locale/pt_BR/LC_MESSAGES/*',
                                 'locale/pt_PT/LC_MESSAGES/*',
                                 'locale/ro/LC_MESSAGES/*',
                                 'locale/ru/LC_MESSAGES/*',
                                 'locale/sk_SK/LC_MESSAGES/*',
                                 'locale/sl/LC_MESSAGES/*',
                                 'locale/sv/LC_MESSAGES/*',
                                 'locale/tet/LC_MESSAGES/*',
                                 'locale/th/LC_MESSAGES/*',
                                 'locale/tr/LC_MESSAGES/*',
                                 'locale/tr_TR/LC_MESSAGES/*',
                                 'locale/uk/LC_MESSAGES/*',
                                 'locale/vi/LC_MESSAGES/*',
                                 'locale/zh_Hans/LC_MESSAGES/*',
                                 'locale/zh_Hant/LC_MESSAGES/*',
                                 'static/table_block/css/vendor/*',
                                 'static/table_block/js/*',
                                 'static/table_block/js/vendor/*',
                                 'templates/*',
                                 'templates/table_block/*',
                                 'templates/table_block/blocks/*'],
 'shatail.contrib.typed_table_block': ['locale/cy/LC_MESSAGES/*',
                                       'locale/de/LC_MESSAGES/*',
                                       'locale/el/LC_MESSAGES/*',
                                       'locale/en/LC_MESSAGES/*',
                                       'locale/es/LC_MESSAGES/*',
                                       'locale/fi/LC_MESSAGES/*',
                                       'locale/fr/LC_MESSAGES/*',
                                       'locale/gl/LC_MESSAGES/*',
                                       'locale/hu/LC_MESSAGES/*',
                                       'locale/is_IS/LC_MESSAGES/*',
                                       'locale/it/LC_MESSAGES/*',
                                       'locale/nl/LC_MESSAGES/*',
                                       'locale/pt_BR/LC_MESSAGES/*',
                                       'locale/pt_PT/LC_MESSAGES/*',
                                       'locale/ro/LC_MESSAGES/*',
                                       'locale/ru/LC_MESSAGES/*',
                                       'locale/sl/LC_MESSAGES/*',
                                       'locale/sv/LC_MESSAGES/*',
                                       'locale/uk/LC_MESSAGES/*',
                                       'locale/zh_Hans/LC_MESSAGES/*',
                                       'locale/zh_Hant/LC_MESSAGES/*',
                                       'static_src/typed_table_block/scss/*',
                                       'templates/typed_table_block/*'],
 'shatail.documents': ['locale/af/LC_MESSAGES/*',
                       'locale/ar/LC_MESSAGES/*',
                       'locale/az_AZ/LC_MESSAGES/*',
                       'locale/be/LC_MESSAGES/*',
                       'locale/bg/LC_MESSAGES/*',
                       'locale/bn/LC_MESSAGES/*',
                       'locale/ca/LC_MESSAGES/*',
                       'locale/cs/LC_MESSAGES/*',
                       'locale/cy/LC_MESSAGES/*',
                       'locale/da/LC_MESSAGES/*',
                       'locale/de/LC_MESSAGES/*',
                       'locale/el/LC_MESSAGES/*',
                       'locale/en/LC_MESSAGES/*',
                       'locale/es/LC_MESSAGES/*',
                       'locale/et/LC_MESSAGES/*',
                       'locale/eu/LC_MESSAGES/*',
                       'locale/fa/LC_MESSAGES/*',
                       'locale/fi/LC_MESSAGES/*',
                       'locale/fr/LC_MESSAGES/*',
                       'locale/gl/LC_MESSAGES/*',
                       'locale/he_IL/LC_MESSAGES/*',
                       'locale/hr_HR/LC_MESSAGES/*',
                       'locale/ht/LC_MESSAGES/*',
                       'locale/hu/LC_MESSAGES/*',
                       'locale/id_ID/LC_MESSAGES/*',
                       'locale/is_IS/LC_MESSAGES/*',
                       'locale/it/LC_MESSAGES/*',
                       'locale/ja/LC_MESSAGES/*',
                       'locale/ka/LC_MESSAGES/*',
                       'locale/ko/LC_MESSAGES/*',
                       'locale/lt/LC_MESSAGES/*',
                       'locale/lv/LC_MESSAGES/*',
                       'locale/mi/LC_MESSAGES/*',
                       'locale/mn/LC_MESSAGES/*',
                       'locale/my/LC_MESSAGES/*',
                       'locale/nb/LC_MESSAGES/*',
                       'locale/nl/LC_MESSAGES/*',
                       'locale/pl/LC_MESSAGES/*',
                       'locale/pt_BR/LC_MESSAGES/*',
                       'locale/pt_PT/LC_MESSAGES/*',
                       'locale/ro/LC_MESSAGES/*',
                       'locale/ru/LC_MESSAGES/*',
                       'locale/sk_SK/LC_MESSAGES/*',
                       'locale/sl/LC_MESSAGES/*',
                       'locale/sr/LC_MESSAGES/*',
                       'locale/sv/LC_MESSAGES/*',
                       'locale/tet/LC_MESSAGES/*',
                       'locale/th/LC_MESSAGES/*',
                       'locale/tr/LC_MESSAGES/*',
                       'locale/tr_TR/LC_MESSAGES/*',
                       'locale/uk/LC_MESSAGES/*',
                       'locale/vi/LC_MESSAGES/*',
                       'locale/zh/LC_MESSAGES/*',
                       'locale/zh_Hans/LC_MESSAGES/*',
                       'locale/zh_Hant/LC_MESSAGES/*',
                       'static_src/*',
                       'static_src/shataildocs/*',
                       'static_src/shataildocs/js/*',
                       'static_src/shataildocs/scss/*',
                       'templates/*',
                       'templates/shataildocs/*',
                       'templates/shataildocs/bulk_actions/*',
                       'templates/shataildocs/chooser/*',
                       'templates/shataildocs/documents/*',
                       'templates/shataildocs/homepage/*',
                       'templates/shataildocs/multiple/*',
                       'templates/shataildocs/permissions/*',
                       'templates/shataildocs/permissions/includes/*',
                       'templates/shataildocs/tables/*',
                       'templates/shataildocs/widgets/*'],
 'shatail.embeds': ['locale/ar/LC_MESSAGES/*',
                    'locale/az_AZ/LC_MESSAGES/*',
                    'locale/be/LC_MESSAGES/*',
                    'locale/bg/LC_MESSAGES/*',
                    'locale/bn/LC_MESSAGES/*',
                    'locale/ca/LC_MESSAGES/*',
                    'locale/cs/LC_MESSAGES/*',
                    'locale/cy/LC_MESSAGES/*',
                    'locale/da/LC_MESSAGES/*',
                    'locale/de/LC_MESSAGES/*',
                    'locale/el/LC_MESSAGES/*',
                    'locale/en/LC_MESSAGES/*',
                    'locale/es/LC_MESSAGES/*',
                    'locale/et/LC_MESSAGES/*',
                    'locale/fa/LC_MESSAGES/*',
                    'locale/fi/LC_MESSAGES/*',
                    'locale/fr/LC_MESSAGES/*',
                    'locale/gl/LC_MESSAGES/*',
                    'locale/he_IL/LC_MESSAGES/*',
                    'locale/hr_HR/LC_MESSAGES/*',
                    'locale/ht/LC_MESSAGES/*',
                    'locale/hu/LC_MESSAGES/*',
                    'locale/id_ID/LC_MESSAGES/*',
                    'locale/is_IS/LC_MESSAGES/*',
                    'locale/it/LC_MESSAGES/*',
                    'locale/ja/LC_MESSAGES/*',
                    'locale/ko/LC_MESSAGES/*',
                    'locale/lt/LC_MESSAGES/*',
                    'locale/lv/LC_MESSAGES/*',
                    'locale/mi/LC_MESSAGES/*',
                    'locale/mn/LC_MESSAGES/*',
                    'locale/my/LC_MESSAGES/*',
                    'locale/nb/LC_MESSAGES/*',
                    'locale/nl/LC_MESSAGES/*',
                    'locale/pl/LC_MESSAGES/*',
                    'locale/pt_BR/LC_MESSAGES/*',
                    'locale/pt_PT/LC_MESSAGES/*',
                    'locale/ro/LC_MESSAGES/*',
                    'locale/ru/LC_MESSAGES/*',
                    'locale/sk_SK/LC_MESSAGES/*',
                    'locale/sl/LC_MESSAGES/*',
                    'locale/sv/LC_MESSAGES/*',
                    'locale/tet/LC_MESSAGES/*',
                    'locale/th/LC_MESSAGES/*',
                    'locale/tr/LC_MESSAGES/*',
                    'locale/tr_TR/LC_MESSAGES/*',
                    'locale/uk/LC_MESSAGES/*',
                    'locale/vi/LC_MESSAGES/*',
                    'locale/zh/LC_MESSAGES/*',
                    'locale/zh_Hans/LC_MESSAGES/*',
                    'locale/zh_Hant/LC_MESSAGES/*',
                    'static_src/shatailembeds/js/*',
                    'templates/shatailembeds/*',
                    'templates/shatailembeds/chooser/*'],
 'shatail.images': ['check_files/*',
                    'locale/af/LC_MESSAGES/*',
                    'locale/ar/LC_MESSAGES/*',
                    'locale/az_AZ/LC_MESSAGES/*',
                    'locale/be/LC_MESSAGES/*',
                    'locale/bg/LC_MESSAGES/*',
                    'locale/bn/LC_MESSAGES/*',
                    'locale/ca/LC_MESSAGES/*',
                    'locale/cs/LC_MESSAGES/*',
                    'locale/cy/LC_MESSAGES/*',
                    'locale/da/LC_MESSAGES/*',
                    'locale/de/LC_MESSAGES/*',
                    'locale/el/LC_MESSAGES/*',
                    'locale/en/LC_MESSAGES/*',
                    'locale/es/LC_MESSAGES/*',
                    'locale/et/LC_MESSAGES/*',
                    'locale/eu/LC_MESSAGES/*',
                    'locale/fa/LC_MESSAGES/*',
                    'locale/fi/LC_MESSAGES/*',
                    'locale/fr/LC_MESSAGES/*',
                    'locale/gl/LC_MESSAGES/*',
                    'locale/he_IL/LC_MESSAGES/*',
                    'locale/hr_HR/LC_MESSAGES/*',
                    'locale/ht/LC_MESSAGES/*',
                    'locale/hu/LC_MESSAGES/*',
                    'locale/hy/LC_MESSAGES/*',
                    'locale/id_ID/LC_MESSAGES/*',
                    'locale/is_IS/LC_MESSAGES/*',
                    'locale/it/LC_MESSAGES/*',
                    'locale/ja/LC_MESSAGES/*',
                    'locale/ka/LC_MESSAGES/*',
                    'locale/ko/LC_MESSAGES/*',
                    'locale/lt/LC_MESSAGES/*',
                    'locale/lv/LC_MESSAGES/*',
                    'locale/mi/LC_MESSAGES/*',
                    'locale/mn/LC_MESSAGES/*',
                    'locale/my/LC_MESSAGES/*',
                    'locale/nb/LC_MESSAGES/*',
                    'locale/nl/LC_MESSAGES/*',
                    'locale/pl/LC_MESSAGES/*',
                    'locale/pt_BR/LC_MESSAGES/*',
                    'locale/pt_PT/LC_MESSAGES/*',
                    'locale/ro/LC_MESSAGES/*',
                    'locale/ru/LC_MESSAGES/*',
                    'locale/sk_SK/LC_MESSAGES/*',
                    'locale/sl/LC_MESSAGES/*',
                    'locale/sv/LC_MESSAGES/*',
                    'locale/tet/LC_MESSAGES/*',
                    'locale/th/LC_MESSAGES/*',
                    'locale/tr/LC_MESSAGES/*',
                    'locale/tr_TR/LC_MESSAGES/*',
                    'locale/uk/LC_MESSAGES/*',
                    'locale/vi/LC_MESSAGES/*',
                    'locale/zh/LC_MESSAGES/*',
                    'locale/zh_Hans/LC_MESSAGES/*',
                    'locale/zh_Hant/LC_MESSAGES/*',
                    'static_src/shatailimages/css/vendor/*',
                    'static_src/shatailimages/js/*',
                    'static_src/shatailimages/js/vendor/*',
                    'static_src/shatailimages/scss/*',
                    'templates/shatailimages/bulk_actions/*',
                    'templates/shatailimages/chooser/*',
                    'templates/shatailimages/homepage/*',
                    'templates/shatailimages/images/*',
                    'templates/shatailimages/multiple/*',
                    'templates/shatailimages/permissions/includes/*',
                    'templates/shatailimages/widgets/*'],
 'shatail.images.tests': ['image_files/*'],
 'shatail.locales': ['locale/ar/LC_MESSAGES/*',
                     'locale/be/LC_MESSAGES/*',
                     'locale/bg/LC_MESSAGES/*',
                     'locale/ca/LC_MESSAGES/*',
                     'locale/cs/LC_MESSAGES/*',
                     'locale/cy/LC_MESSAGES/*',
                     'locale/da/LC_MESSAGES/*',
                     'locale/de/LC_MESSAGES/*',
                     'locale/el/LC_MESSAGES/*',
                     'locale/en/LC_MESSAGES/*',
                     'locale/es/LC_MESSAGES/*',
                     'locale/et/LC_MESSAGES/*',
                     'locale/fa/LC_MESSAGES/*',
                     'locale/fi/LC_MESSAGES/*',
                     'locale/fr/LC_MESSAGES/*',
                     'locale/gl/LC_MESSAGES/*',
                     'locale/he_IL/LC_MESSAGES/*',
                     'locale/hr_HR/LC_MESSAGES/*',
                     'locale/hu/LC_MESSAGES/*',
                     'locale/id_ID/LC_MESSAGES/*',
                     'locale/is_IS/LC_MESSAGES/*',
                     'locale/it/LC_MESSAGES/*',
                     'locale/ja/LC_MESSAGES/*',
                     'locale/ko/LC_MESSAGES/*',
                     'locale/lt/LC_MESSAGES/*',
                     'locale/lv/LC_MESSAGES/*',
                     'locale/mi/LC_MESSAGES/*',
                     'locale/mn/LC_MESSAGES/*',
                     'locale/my/LC_MESSAGES/*',
                     'locale/nb/LC_MESSAGES/*',
                     'locale/nl/LC_MESSAGES/*',
                     'locale/pl/LC_MESSAGES/*',
                     'locale/pt_BR/LC_MESSAGES/*',
                     'locale/pt_PT/LC_MESSAGES/*',
                     'locale/ro/LC_MESSAGES/*',
                     'locale/ru/LC_MESSAGES/*',
                     'locale/sk_SK/LC_MESSAGES/*',
                     'locale/sl/LC_MESSAGES/*',
                     'locale/sv/LC_MESSAGES/*',
                     'locale/tet/LC_MESSAGES/*',
                     'locale/th/LC_MESSAGES/*',
                     'locale/tr/LC_MESSAGES/*',
                     'locale/tr_TR/LC_MESSAGES/*',
                     'locale/uk/LC_MESSAGES/*',
                     'locale/vi/LC_MESSAGES/*',
                     'locale/zh/LC_MESSAGES/*',
                     'locale/zh_Hans/LC_MESSAGES/*',
                     'locale/zh_Hant/LC_MESSAGES/*',
                     'templates/shataillocales/*'],
 'shatail.project_template.home': ['static/*',
                                   'static/css/*',
                                   'templates/*',
                                   'templates/home/*'],
 'shatail.project_template.project_name': ['static/css/*',
                                           'static/js/*',
                                           'templates/*'],
 'shatail.project_template.search': ['templates/*', 'templates/search/*'],
 'shatail.search': ['locale/af/LC_MESSAGES/*',
                    'locale/ar/LC_MESSAGES/*',
                    'locale/be/LC_MESSAGES/*',
                    'locale/bg/LC_MESSAGES/*',
                    'locale/bn/LC_MESSAGES/*',
                    'locale/ca/LC_MESSAGES/*',
                    'locale/cs/LC_MESSAGES/*',
                    'locale/cy/LC_MESSAGES/*',
                    'locale/da/LC_MESSAGES/*',
                    'locale/de/LC_MESSAGES/*',
                    'locale/el/LC_MESSAGES/*',
                    'locale/en/LC_MESSAGES/*',
                    'locale/es/LC_MESSAGES/*',
                    'locale/et/LC_MESSAGES/*',
                    'locale/eu/LC_MESSAGES/*',
                    'locale/fa/LC_MESSAGES/*',
                    'locale/fi/LC_MESSAGES/*',
                    'locale/fr/LC_MESSAGES/*',
                    'locale/gl/LC_MESSAGES/*',
                    'locale/he_IL/LC_MESSAGES/*',
                    'locale/hr_HR/LC_MESSAGES/*',
                    'locale/ht/LC_MESSAGES/*',
                    'locale/hu/LC_MESSAGES/*',
                    'locale/id_ID/LC_MESSAGES/*',
                    'locale/is_IS/LC_MESSAGES/*',
                    'locale/it/LC_MESSAGES/*',
                    'locale/ja/LC_MESSAGES/*',
                    'locale/ka/LC_MESSAGES/*',
                    'locale/ko/LC_MESSAGES/*',
                    'locale/lt/LC_MESSAGES/*',
                    'locale/lv/LC_MESSAGES/*',
                    'locale/mi/LC_MESSAGES/*',
                    'locale/mn/LC_MESSAGES/*',
                    'locale/my/LC_MESSAGES/*',
                    'locale/nb/LC_MESSAGES/*',
                    'locale/nl/LC_MESSAGES/*',
                    'locale/pl/LC_MESSAGES/*',
                    'locale/pt_BR/LC_MESSAGES/*',
                    'locale/pt_PT/LC_MESSAGES/*',
                    'locale/ro/LC_MESSAGES/*',
                    'locale/ru/LC_MESSAGES/*',
                    'locale/sk_SK/LC_MESSAGES/*',
                    'locale/sl/LC_MESSAGES/*',
                    'locale/sv/LC_MESSAGES/*',
                    'locale/tet/LC_MESSAGES/*',
                    'locale/th/LC_MESSAGES/*',
                    'locale/tr/LC_MESSAGES/*',
                    'locale/tr_TR/LC_MESSAGES/*',
                    'locale/uk/LC_MESSAGES/*',
                    'locale/vi/LC_MESSAGES/*',
                    'locale/zh/LC_MESSAGES/*',
                    'locale/zh_Hans/LC_MESSAGES/*',
                    'locale/zh_Hant/LC_MESSAGES/*',
                    'static_src/shatailsearch/js/*',
                    'templates/shatailsearch/*',
                    'templates/shatailsearch/queries/*',
                    'templates/shatailsearch/queries/chooser/*'],
 'shatail.sites': ['locale/ar/LC_MESSAGES/*',
                   'locale/be/LC_MESSAGES/*',
                   'locale/bn/LC_MESSAGES/*',
                   'locale/ca/LC_MESSAGES/*',
                   'locale/cs/LC_MESSAGES/*',
                   'locale/cy/LC_MESSAGES/*',
                   'locale/da/LC_MESSAGES/*',
                   'locale/de/LC_MESSAGES/*',
                   'locale/el/LC_MESSAGES/*',
                   'locale/en/LC_MESSAGES/*',
                   'locale/es/LC_MESSAGES/*',
                   'locale/et/LC_MESSAGES/*',
                   'locale/fa/LC_MESSAGES/*',
                   'locale/fi/LC_MESSAGES/*',
                   'locale/fr/LC_MESSAGES/*',
                   'locale/gl/LC_MESSAGES/*',
                   'locale/he_IL/LC_MESSAGES/*',
                   'locale/hr_HR/LC_MESSAGES/*',
                   'locale/ht/LC_MESSAGES/*',
                   'locale/hu/LC_MESSAGES/*',
                   'locale/id_ID/LC_MESSAGES/*',
                   'locale/is_IS/LC_MESSAGES/*',
                   'locale/it/LC_MESSAGES/*',
                   'locale/ja/LC_MESSAGES/*',
                   'locale/ka/LC_MESSAGES/*',
                   'locale/ko/LC_MESSAGES/*',
                   'locale/lt/LC_MESSAGES/*',
                   'locale/lv/LC_MESSAGES/*',
                   'locale/mi/LC_MESSAGES/*',
                   'locale/mn/LC_MESSAGES/*',
                   'locale/my/LC_MESSAGES/*',
                   'locale/nb/LC_MESSAGES/*',
                   'locale/nl/LC_MESSAGES/*',
                   'locale/pl/LC_MESSAGES/*',
                   'locale/pt_BR/LC_MESSAGES/*',
                   'locale/pt_PT/LC_MESSAGES/*',
                   'locale/ro/LC_MESSAGES/*',
                   'locale/ru/LC_MESSAGES/*',
                   'locale/sk_SK/LC_MESSAGES/*',
                   'locale/sl/LC_MESSAGES/*',
                   'locale/sr/LC_MESSAGES/*',
                   'locale/sv/LC_MESSAGES/*',
                   'locale/tet/LC_MESSAGES/*',
                   'locale/th/LC_MESSAGES/*',
                   'locale/tr/LC_MESSAGES/*',
                   'locale/tr_TR/LC_MESSAGES/*',
                   'locale/uk/LC_MESSAGES/*',
                   'locale/vi/LC_MESSAGES/*',
                   'locale/zh_Hans/LC_MESSAGES/*',
                   'locale/zh_Hant/LC_MESSAGES/*',
                   'templates/*',
                   'templates/shatailsites/*'],
 'shatail.snippets': ['locale/af/LC_MESSAGES/*',
                      'locale/ar/LC_MESSAGES/*',
                      'locale/az_AZ/LC_MESSAGES/*',
                      'locale/be/LC_MESSAGES/*',
                      'locale/bg/LC_MESSAGES/*',
                      'locale/bn/LC_MESSAGES/*',
                      'locale/ca/LC_MESSAGES/*',
                      'locale/cs/LC_MESSAGES/*',
                      'locale/cy/LC_MESSAGES/*',
                      'locale/da/LC_MESSAGES/*',
                      'locale/de/LC_MESSAGES/*',
                      'locale/el/LC_MESSAGES/*',
                      'locale/en/LC_MESSAGES/*',
                      'locale/es/LC_MESSAGES/*',
                      'locale/et/LC_MESSAGES/*',
                      'locale/eu/LC_MESSAGES/*',
                      'locale/fa/LC_MESSAGES/*',
                      'locale/fi/LC_MESSAGES/*',
                      'locale/fr/LC_MESSAGES/*',
                      'locale/gl/LC_MESSAGES/*',
                      'locale/he_IL/LC_MESSAGES/*',
                      'locale/hr_HR/LC_MESSAGES/*',
                      'locale/ht/LC_MESSAGES/*',
                      'locale/hu/LC_MESSAGES/*',
                      'locale/id_ID/LC_MESSAGES/*',
                      'locale/is_IS/LC_MESSAGES/*',
                      'locale/it/LC_MESSAGES/*',
                      'locale/ja/LC_MESSAGES/*',
                      'locale/ka/LC_MESSAGES/*',
                      'locale/ko/LC_MESSAGES/*',
                      'locale/lt/LC_MESSAGES/*',
                      'locale/lv/LC_MESSAGES/*',
                      'locale/mi/LC_MESSAGES/*',
                      'locale/mn/LC_MESSAGES/*',
                      'locale/my/LC_MESSAGES/*',
                      'locale/nb/LC_MESSAGES/*',
                      'locale/nl/LC_MESSAGES/*',
                      'locale/pl/LC_MESSAGES/*',
                      'locale/pt_BR/LC_MESSAGES/*',
                      'locale/pt_PT/LC_MESSAGES/*',
                      'locale/ro/LC_MESSAGES/*',
                      'locale/ru/LC_MESSAGES/*',
                      'locale/sk_SK/LC_MESSAGES/*',
                      'locale/sl/LC_MESSAGES/*',
                      'locale/sr/LC_MESSAGES/*',
                      'locale/sv/LC_MESSAGES/*',
                      'locale/tet/LC_MESSAGES/*',
                      'locale/th/LC_MESSAGES/*',
                      'locale/tr/LC_MESSAGES/*',
                      'locale/tr_TR/LC_MESSAGES/*',
                      'locale/uk/LC_MESSAGES/*',
                      'locale/vi/LC_MESSAGES/*',
                      'locale/zh/LC_MESSAGES/*',
                      'locale/zh_Hans/LC_MESSAGES/*',
                      'locale/zh_Hant/LC_MESSAGES/*',
                      'static_src/shatailsnippets/js/*',
                      'templates/shatailsnippets/chooser/*',
                      'templates/shatailsnippets/snippets/*',
                      'templates/shatailsnippets/snippets/action_menu/*',
                      'templates/shatailsnippets/widgets/*'],
 'shatail.test.customuser': ['fixtures/*'],
 'shatail.test.demosite': ['fixtures/*'],
 'shatail.test.emailuser': ['fixtures/*'],
 'shatail.test.modeladmintest': ['fixtures/*'],
 'shatail.test.routablepage': ['templates/*', 'templates/routablepagetests/*'],
 'shatail.test.search': ['fixtures/*'],
 'shatail.test.testapp': ['fixtures/*',
                          'jinja2_templates/*',
                          'jinja2_templates/tests/jinja2/*',
                          'templates/tests/*',
                          'templates/tests/block_forms/*',
                          'templates/tests/blocks/*',
                          'templates/tests/includes/*'],
 'shatail.users': ['locale/af/LC_MESSAGES/*',
                   'locale/ar/LC_MESSAGES/*',
                   'locale/az_AZ/LC_MESSAGES/*',
                   'locale/be/LC_MESSAGES/*',
                   'locale/bg/LC_MESSAGES/*',
                   'locale/bn/LC_MESSAGES/*',
                   'locale/ca/LC_MESSAGES/*',
                   'locale/cs/LC_MESSAGES/*',
                   'locale/cy/LC_MESSAGES/*',
                   'locale/da/LC_MESSAGES/*',
                   'locale/de/LC_MESSAGES/*',
                   'locale/el/LC_MESSAGES/*',
                   'locale/en/LC_MESSAGES/*',
                   'locale/es/LC_MESSAGES/*',
                   'locale/et/LC_MESSAGES/*',
                   'locale/eu/LC_MESSAGES/*',
                   'locale/fa/LC_MESSAGES/*',
                   'locale/fi/LC_MESSAGES/*',
                   'locale/fr/LC_MESSAGES/*',
                   'locale/gl/LC_MESSAGES/*',
                   'locale/he_IL/LC_MESSAGES/*',
                   'locale/hr_HR/LC_MESSAGES/*',
                   'locale/ht/LC_MESSAGES/*',
                   'locale/hu/LC_MESSAGES/*',
                   'locale/hy/LC_MESSAGES/*',
                   'locale/id_ID/LC_MESSAGES/*',
                   'locale/is_IS/LC_MESSAGES/*',
                   'locale/it/LC_MESSAGES/*',
                   'locale/ja/LC_MESSAGES/*',
                   'locale/ka/LC_MESSAGES/*',
                   'locale/ko/LC_MESSAGES/*',
                   'locale/lt/LC_MESSAGES/*',
                   'locale/lv/LC_MESSAGES/*',
                   'locale/mi/LC_MESSAGES/*',
                   'locale/mn/LC_MESSAGES/*',
                   'locale/my/LC_MESSAGES/*',
                   'locale/nb/LC_MESSAGES/*',
                   'locale/nl/LC_MESSAGES/*',
                   'locale/pl/LC_MESSAGES/*',
                   'locale/pt_BR/LC_MESSAGES/*',
                   'locale/pt_PT/LC_MESSAGES/*',
                   'locale/ro/LC_MESSAGES/*',
                   'locale/ru/LC_MESSAGES/*',
                   'locale/sk_SK/LC_MESSAGES/*',
                   'locale/sl/LC_MESSAGES/*',
                   'locale/sr/LC_MESSAGES/*',
                   'locale/sv/LC_MESSAGES/*',
                   'locale/tet/LC_MESSAGES/*',
                   'locale/th/LC_MESSAGES/*',
                   'locale/tr/LC_MESSAGES/*',
                   'locale/tr_TR/LC_MESSAGES/*',
                   'locale/uk/LC_MESSAGES/*',
                   'locale/vi/LC_MESSAGES/*',
                   'locale/zh/LC_MESSAGES/*',
                   'locale/zh_Hans/LC_MESSAGES/*',
                   'locale/zh_Hant/LC_MESSAGES/*',
                   'static_src/shatailusers/js/*',
                   'static_src/shatailusers/scss/*',
                   'templates/shatailusers/bulk_actions/*',
                   'templates/shatailusers/groups/*',
                   'templates/shatailusers/groups/includes/*',
                   'templates/shatailusers/users/*']}

install_requires = \
['importlib_metadata>=3.4.0,<4.0.0']

setup_kwargs = {
    'name': 'shatail',
    'version': '0.1.0',
    'description': '根据Wagtail修改的Django CMS 系统。',
    'long_description': '# Shatail\n\n\n[![PyPI version](https://badge.fury.io/py/shatail.svg)](https://badge.fury.io/py/shatail)\n![versions](https://img.shields.io/pypi/pyversions/shatail.svg)\n[![GitHub license](https://img.shields.io/github/license/mgancita/shatail.svg)](https://github.com/mgancita/shatail/blob/main/LICENSE)\n\n\n[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)\n\n\n根据Wagtail修改的Django CMS 系统。\n\n\n- 开源许可: BSD-3-Clause\n- 文档: https://llango.github.io/shatail.\n\n\n## 特征\n\n* TODO\n\n## 制作\n\n\n该包使用 [Cookiecutter](https://github.com/audreyr/cookiecutter) 和 [`llango/cookiecutter-mkdoc-shapackage`](https://github.com/llango/cookiecutter-mkdoc-shapackage/) 项目模版创建。\n',
    'author': 'Rontomai',
    'author_email': 'rontomai@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/llango/shatail',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)



from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class ShatailLocalesAppConfig(AppConfig):
    name = "shatail.locales"
    label = "shataillocales"
    verbose_name = _("Shatail locales")



from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class ShatailSitemapsAppConfig(AppConfig):
    name = "shatail.contrib.sitemaps"
    label = "shatailsitemaps"
    verbose_name = _("Shatail sitemaps")



from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class ShatailRoutablePageTestsAppConfig(AppConfig):
    name = "shatail.test.routablepage"
    label = "routablepagetests"
    verbose_name = _("Shatail routable page tests")
